Index Page
==========

On the top of the index page, you can switch between displaying only your own
posts and displaying posts of all authors.

.. admonition:: Permissions

   In order to view posts of other authors, you must have the “can edit others’
   posts” permission.

   In addition, you can set the default view in the :doc:`Account <account>`
   section.

Below, Posts and Pages are displayed in separate columns.  On the top of
each column, you can create posts by typing their title in the field.

.. warning::

   The post URL will be set based on the post title.  It cannot be changed
   later!

All the posts are displayed under the creation field.  You can :doc:`edit <edit>` or :doc:`delete <delete>`
them.
